@@ -83,8 +83,7 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
                 self.pubsub.ping()
                 self.listen()
             except ConnectionError as err:
-                print("Problem trying to listen, relisten...")
-                print(f"Err: {err}")
+                print(f"Problem trying to listen, relisten... Err: {err}")
             except AttributeError as _:
                 print("None type of msg")
             finally:
@@ -94,6 +93,8 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
         # type: () -> None
 
         for msg in self.pubsub.listen():
+            if self.force_disconnection is True:
+                return
             if msg is not None and isinstance(msg, dict):
                 # Save info in queue.
                 data = self._convert_data(msg['data'])
